@@ -17,8 +17,13 @@ class Config:
     pass
 
 
+class Context:
+    pass
+
+
 logger = logging.getLogger("remotecv")  # pylint: disable=invalid-name
 config = Config()  # pylint: disable=invalid-name
+context = Context()
 
 SINGLE_NODE = "single_node"
 SENTINEL = "sentinel"
@@ -31,7 +36,9 @@ def redis_client():
     if config.redis_mode == SENTINEL:
         return __redis_sentinel_client()
 
-    raise AttributeError(f"redis-mode must be either {SINGLE_NODE} or {SENTINEL}")
+    raise AttributeError(
+        f"redis-mode must be either {SINGLE_NODE} or {SENTINEL}"
+    )
 
 
 def __redis_sentinel_client():
